@@ -1190,9 +1190,22 @@ allgenes <- unique(unlist(V(dag)$annotations))
 genes <- intersect(allgenes, genes_in_PS)
 sim <- dDAGgeneSim(g=dag, genes=genes, method.gene="BM.average", method.term="Resnik", verbose=TRUE)
 
+# it taks one hour using 6 cores
+save(list=c("sim","genes","GS","dag"),file="sim.MP.RData")
+load("sim.MP.RData")
+
+# it taks half an hour using 6 cores
+save(list=c("sim","genes","GS","dag"),file="sim.DO.RData")
+load("sim.DO.RData")
+
+# it taks 7 min using 6 cores
 save(list=c("sim","genes","GS","dag"),file="sim.HPPA.RData")
 load("sim.HPPA.RData")
 
+# scp gg-pc4:./sim.* ./
+
+
+
 a <- sapply(GS$gs, function(x){
     ind <- match(x,genes)
     flag <- ind[!is.na(ind)]
@@ -1233,8 +1246,18 @@ for(i in 1:length(GS$gs)){
 }
 
 
+
+
 dev.new()
-plot(a, type='b')
+par(las=2, mar=c(15,5,2,2)) # all axis labels horizontal
+plot(a, type='b', xlab='', ylab="Average of MP-based semantic similarity at the ancestor and earlier", xaxt="n")
+set_info <- as.character(GS$set_info$name)
+num <- sapply(GS$gs,length)
+labels <- paste(set_info, sep='')
+axis(1, at=1:length(a), labels=labels)
+
+
+
 
 
 a <- rep(NA, length(GS$gs))
@@ -1264,13 +1287,5 @@ num <- sapply(split(id,id),length)
 set_info <- as.character(GS$set_info$name[sort(unique(id))])
 labels <- paste(set_info,' (n=', num, ')', sep='')
 par(las=2, mar=c(5,15,2,2)) # all axis labels horizontal
-visBoxplotAdv(formula=value ~ id, data=data, orientation="horizontal", spacing=0.5, labels=labels, ylab=NA, xlab="Average of HP-based semantic similarity to ancestors", boxplot.border = "#0000FF", boxplot.col = "transparent")
+visBoxplotAdv(formula=value ~ id, data=data, orientation="horizontal", cex=0.8, spacing=0.5, labels=labels, ylab=NA, xlab="Average of DO-based semantic similarity to ancestors", boxplot.border = "#0000FF", boxplot.col = "transparent")
 
-
-source("http://bioconductor.org/biocLite.R")
-biocLite(c("foreach","doMC"))
-library(foreach)
-library(doMC)
-registerDoMC(2)
-
-# Parallel computation depends upon a _parallel backend_ that must be registered before performing the computation. The parallel backends available will be system-specific, but include 'doParallel', which uses R's built-in 'parallel' package, 'doMC' which uses the 'multicore' package, and 'doSNOW'. Each parallel backend has a specific registration function, such as 'registerDoParallel' or 'registerDoSNOW'
