@@ -5,7 +5,7 @@ list(
     
     index = list(
         sd_section("Network analysis and visualisation functions",
-            "These functions are used for network analysis and visualisation, including: identification of gene-active dynamic networks; network-based sample classifications and visualisations on 2D sample landscape; and random walk with restart (RWR) for network affinity calculation.",
+            "These functions are used for network analysis and visualisation, including: identification of gene-active networks, and network-based sample classifications and visualisations on 2D sample landscape.",
             c(
                 'dNetPipeline',
                 'dNetReorder',
@@ -19,7 +19,6 @@ list(
                 'dNetFind',
                 'dCommSignif',
                 'dContrast',
-                'dRWR',
                 'visNet',
                 'visNetMul',
                 'visNetReorder',
@@ -29,6 +28,15 @@ list(
                 'dRDataLoader'
             )
         ),
+        sd_section("Random Walk with Restart (RWR)",
+            "These functions are used for RWR-based analysis, including: calculation of network affinity and estimation of contact strength between samples.",
+            c(
+                'dRWR',
+                'dRWRcontact',
+                'dRWRpipeline',
+                'dCheckParallel'
+            )
+        ),
         sd_section("Enrichment analysis and visualisation functions",
             "These functions are used for enrichment analysis and visualisation, including: enrichment analysis (Fisher's exact test, Hypergeometric test or Binomial test) that can account for the hierarchy of the ontology; and gene set enrichment analysis (GSEA).",
             c(
@@ -40,7 +48,7 @@ list(
                 'visGSEA'
             )
         ),
-        sd_section("Built-in ontologies, and analysis and visualisation functions",
+        sd_section("Built-in ontologies, and supporting functions for analysis and visualisation",
             "These ontologies each are represented as a direct acyclic graph (DAG). DAG is stored as an object of the class 'igraph', which can be processed by various analysis and visualisation functions.",
             c(
                 "ig.GOMF",
@@ -57,6 +65,9 @@ list(
                 'dDAGtip',
                 'dDAGlevel',
                 'dDAGannotate',
+                'dDAGancestor',
+                'dDAGtermSim',
+                'dDAGgeneSim',
                 "visDAG"
             )
         ),
@@ -195,6 +206,13 @@ list(
                 "CLL",
                 "TCGA_mutations"
             )
+        ),
+        sd_section("Domain-centric databases in Eukaryotes",
+            "These databases are used for domain-centric analysis.",
+            c(
+                "Ancestral_domainome",
+                "eTOL"
+            )
         )
     ),
     
